#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-test
version:              1.6.23
visibility:           public
id:                   yesod-test-1.6.23-8e0kQn37eW4Lhq3CH43I1Z
key:                  yesod-test-1.6.23-8e0kQn37eW4Lhq3CH43I1Z
license:              MIT
maintainer:           Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author:               Nubis <nubis@woobiz.com.ar>
stability:            Experimental
homepage:             http://www.yesodweb.com
synopsis:             integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>

category:             Web, Yesod, Testing
abi:                  705cd066e6d8643f4c3fa283d59f51df
exposed:              True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.Internal
    Yesod.Test.Internal.SIO Yesod.Test.TransversingCSS

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-test-1.6.23
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-test-1.6.23
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-test-1.6.23
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-test
hs-libraries:         HSyesod-test-1.6.23-8e0kQn37eW4Lhq3CH43I1Z
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    aeson-2.2.1.0-1TOI5ELuqi01VCY8v7ADie
    attoparsec-0.14.4-8Ihrc92tki9CPtxJ7iMWhq base-4.18.2.1
    blaze-builder-0.4.4.1-FueEPpNIqsb4bYeizJE1KI
    blaze-html-0.9.2.0-KqwG3G8bIEdCBkJGh5vAX5
    blaze-markup-0.8.3.0-2zM85WYFmjX1BPy9tSFYFy bytestring-0.11.5.3
    case-insensitive-1.2.1.0-GQhuCOunwpP4Wu7eC91bZR
    conduit-1.3.6.1-8P16HBmakUKG1It6ArZYEY containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    hspec-core-2.11.5-QN4f9Q6hz765LOhbRsPK5
    html-conduit-1.3.2.2-10Mp8y4lumA3DAz5iyjVG9
    http-types-0.12.4-CCQmPdMOAQMGVpO7SZrjGJ
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-3.1.4.0-9dONp0onFcbAlDBEoFNGkb
    pretty-show-1.10-EXsS4VwIV5tJ56gbmVdfrR process-1.6.19.0 text-2.0.2
    time-1.12.2 transformers-0.6.1.0 wai-3.2.4-3XyCh5m71lWJYF48VLLZUp
    wai-extra-3.1.18-LZb0ZvCfLGtGdgg4u5HHu3
    xml-conduit-1.9.1.4-KzsVcANkifF2lJJF05P91u
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    yesod-core-1.6.27.1-5nww1PtNlse5fK9VkYdWN4

haddock-interfaces:   /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html:         /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

